==> estateplat-common-1.2.3-20180510.041431-81-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtJftjsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    商品房交付条件与交付手续历史表(第四章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_jftjsx")
public class FcjyXjspfBaMmhtJftjsx {
    @Id
    private String jflsid;//主键
    private String htlsid;//合同历史表id
    private String jfid;//商品房交付条件与交付手续(第四章)主键
    private String htid;//合同ID
    private String jftjfhx3;//交付条件符合项3
    private String jftj3;//交付条件三
    private String jftj4;//交付条件四
    private String gsqt;//供水其他
    private String gdqt;//供电其他
    private String gnqt;//供暖其他
    private String rqqt;//燃气其他
    private Integer jcssyqjfclfs;//基础设施逾期交付处理方式
    private Double dwxzfwyjje;//第五项支付违约金金额(元)
    private Double dlxzfwyjje;//第六项支付违约金金额(元)
    private Double dqxzfwyjje;//第七项支付违约金金额(元)
    private Integer xcbzjfts;//下次保证交付天数
    private String jcssyqjfqtfs;//基础设施逾期交付其他方式
    private Date ldlqx;//绿地率期限
    private String ldldd;//绿地率达到
    private Date fszdlqx;//非市政道路期限
    private String fszdldd;//非市政道路达到
    private Date ghcwqx;//规划车位期限
    private String ghcwdd;//规划车位达到
    private Date wyfwyfqx;//物业服务用房期限
    private String wyfwyfdd;//物业服务用房达到
    private Date ylwsjgqx;//医疗卫生机构期限
    private String ylwsjgdd;//医疗卫生机构达到
    private Date yeyqx;//幼儿园期限
    private String yeydd;//幼儿园达到
    private Date xxqx;//学校期限
    private String xxdd;//学校达到
    private String ptssqt1;//配套设施其他1
    private String ptssqt2;//配套设施其他2
    private String ldlwddclfs;//绿地率未达到处理方式
    private String fszdlwddclfs;//非市政道路未达到处理方式
    private String ghcwwddclfs;//规划车位未达到处理方式
    private String wyfwwddclfs;//物业服务未达到处理方式
    private String qtsswddclfs;//其他设施未达到处理方式
    private Date jfsj;//交付时间
    private Integer jftzts;//交付通知天数
    private String jfqt;//交付其他
    private Integer xxrnxf;//查验次日起XX日内修复
    private String xfnr1;//修复内容其他1
    private String xfnr2;//修复内容其他2
    private String cywjfcl1;//查验未交付处理1
    private String cywjfcl2;//查验未交付处理2
    private Integer jfyqclfs;//交付逾期处理方式
    private Integer jfyqxxrn;//交付逾期XX日内
    private Double jfyqxrnwfzxwyj;//交付逾期X日内万分之X违约金
    private Integer jfyqcxxr;//交付逾期超XX日
    private Integer yqcjflx;//逾期超给付利息(日)
    private Double yqcwyj;//逾期超违约金(百分之)
    private Double fjkwfzxwyj;//房价款万分之X违约金
    private String jfyqqtfs;//交付逾期其他方式
    private String jftjfhx4;//交付条件符合项4
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getJflsid() {
        return jflsid;
    }

    public void setJflsid(String jflsid) {
        this.jflsid = jflsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getJfid() {
        return jfid;
    }

    public void setJfid(String jfid) {
        this.jfid = jfid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJftjfhx3() {
        return jftjfhx3;
    }

    public void setJftjfhx3(String jftjfhx3) {
        this.jftjfhx3 = jftjfhx3;
    }

    public String getJftj3() {
        return jftj3;
    }

    public void setJftj3(String jftj3) {
        this.jftj3 = jftj3;
    }

    public String getJftj4() {
        return jftj4;
    }

    public void setJftj4(String jftj4) {
        this.jftj4 = jftj4;
    }

    public String getGsqt() {
        return gsqt;
    }

    public void setGsqt(String gsqt) {
        this.gsqt = gsqt;
    }

    public String getGdqt() {
        return gdqt;
    }

    public void setGdqt(String gdqt) {
        this.gdqt = gdqt;
    }

    public String getGnqt() {
        return gnqt;
    }

    public void setGnqt(String gnqt) {
        this.gnqt = gnqt;
    }

    public String getRqqt() {
        return rqqt;
    }

    public void setRqqt(String rqqt) {
        this.rqqt = rqqt;
    }

    public Integer getJcssyqjfclfs() {
        return jcssyqjfclfs;
    }

    public void setJcssyqjfclfs(Integer jcssyqjfclfs) {
        this.jcssyqjfclfs = jcssyqjfclfs;
    }

    public Double getDwxzfwyjje() {
        return dwxzfwyjje;
    }

    public void setDwxzfwyjje(Double dwxzfwyjje) {
        this.dwxzfwyjje = dwxzfwyjje;
    }

    public Double getDlxzfwyjje() {
        return dlxzfwyjje;
    }

    public void setDlxzfwyjje(Double dlxzfwyjje) {
        this.dlxzfwyjje = dlxzfwyjje;
    }

    public Double getDqxzfwyjje() {
        return dqxzfwyjje;
    }

    public void setDqxzfwyjje(Double dqxzfwyjje) {
        this.dqxzfwyjje = dqxzfwyjje;
    }

    public Integer getXcbzjfts() {
        return xcbzjfts;
    }

    public void setXcbzjfts(Integer xcbzjfts) {
        this.xcbzjfts = xcbzjfts;
    }

    public String getJcssyqjfqtfs() {
        return jcssyqjfqtfs;
    }

    public void setJcssyqjfqtfs(String jcssyqjfqtfs) {
        this.jcssyqjfqtfs = jcssyqjfqtfs;
    }

    public Date getLdlqx() {
        return ldlqx;
    }

    public void setLdlqx(Date ldlqx) {
        this.ldlqx = ldlqx;
    }

    public String getLdldd() {
        return ldldd;
    }

    public void setLdldd(String ldldd) {
        this.ldldd = ldldd;
    }

    public Date getFszdlqx() {
        return fszdlqx;
    }

    public void setFszdlqx(Date fszdlqx) {
        this.fszdlqx = fszdlqx;
    }

    public String getFszdldd() {
        return fszdldd;
    }

    public void setFszdldd(String fszdldd) {
        this.fszdldd = fszdldd;
    }

    public Date getGhcwqx() {
        return ghcwqx;
    }

    public void setGhcwqx(Date ghcwqx) {
        this.ghcwqx = ghcwqx;
    }

    public String getGhcwdd() {
        return ghcwdd;
    }

    public void setGhcwdd(String ghcwdd) {
        this.ghcwdd = ghcwdd;
    }

    public Date getWyfwyfqx() {
        return wyfwyfqx;
    }

    public void setWyfwyfqx(Date wyfwyfqx) {
        this.wyfwyfqx = wyfwyfqx;
    }

    public String getWyfwyfdd() {
        return wyfwyfdd;
    }

    public void setWyfwyfdd(String wyfwyfdd) {
        this.wyfwyfdd = wyfwyfdd;
    }

    public Date getYlwsjgqx() {
        return ylwsjgqx;
    }

    public void setYlwsjgqx(Date ylwsjgqx) {
        this.ylwsjgqx = ylwsjgqx;
    }

    public String getYlwsjgdd() {
        return ylwsjgdd;
    }

    public void setYlwsjgdd(String ylwsjgdd) {
        this.ylwsjgdd = ylwsjgdd;
    }

    public Date getYeyqx() {
        return yeyqx;
    }

    public void setYeyqx(Date yeyqx) {
        this.yeyqx = yeyqx;
    }

    public String getYeydd() {
        return yeydd;
    }

    public void setYeydd(String yeydd) {
        this.yeydd = yeydd;
    }

    public Date getXxqx() {
        return xxqx;
    }

    public void setXxqx(Date xxqx) {
        this.xxqx = xxqx;
    }

    public String getXxdd() {
        return xxdd;
    }

    public void setXxdd(String xxdd) {
        this.xxdd = xxdd;
    }

    public String getPtssqt1() {
        return ptssqt1;
    }

    public void setPtssqt1(String ptssqt1) {
        this.ptssqt1 = ptssqt1;
    }

    public String getPtssqt2() {
        return ptssqt2;
    }

    public void setPtssqt2(String ptssqt2) {
        this.ptssqt2 = ptssqt2;
    }

    public String getLdlwddclfs() {
        return ldlwddclfs;
    }

    public void setLdlwddclfs(String ldlwddclfs) {
        this.ldlwddclfs = ldlwddclfs;
    }

    public String getFszdlwddclfs() {
        return fszdlwddclfs;
    }

    public void setFszdlwddclfs(String fszdlwddclfs) {
        this.fszdlwddclfs = fszdlwddclfs;
    }

    public String getGhcwwddclfs() {
        return ghcwwddclfs;
    }

    public void setGhcwwddclfs(String ghcwwddclfs) {
        this.ghcwwddclfs = ghcwwddclfs;
    }

    public String getWyfwwddclfs() {
        return wyfwwddclfs;
    }

    public void setWyfwwddclfs(String wyfwwddclfs) {
        this.wyfwwddclfs = wyfwwddclfs;
    }

    public String getQtsswddclfs() {
        return qtsswddclfs;
    }

    public void setQtsswddclfs(String qtsswddclfs) {
        this.qtsswddclfs = qtsswddclfs;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Integer getJftzts() {
        return jftzts;
    }

    public void setJftzts(Integer jftzts) {
        this.jftzts = jftzts;
    }

    public String getJfqt() {
        return jfqt;
    }

    public void setJfqt(String jfqt) {
        this.jfqt = jfqt;
    }

    public Integer getXxrnxf() {
        return xxrnxf;
    }

    public void setXxrnxf(Integer xxrnxf) {
        this.xxrnxf = xxrnxf;
    }

    public String getXfnr1() {
        return xfnr1;
    }

    public void setXfnr1(String xfnr1) {
        this.xfnr1 = xfnr1;
    }

    public String getXfnr2() {
        return xfnr2;
    }

    public void setXfnr2(String xfnr2) {
        this.xfnr2 = xfnr2;
    }

    public String getCywjfcl1() {
        return cywjfcl1;
    }

    public void setCywjfcl1(String cywjfcl1) {
        this.cywjfcl1 = cywjfcl1;
    }

    public String getCywjfcl2() {
        return cywjfcl2;
    }

    public void setCywjfcl2(String cywjfcl2) {
        this.cywjfcl2 = cywjfcl2;
    }

    public Integer getJfyqclfs() {
        return jfyqclfs;
    }

    public void setJfyqclfs(Integer jfyqclfs) {
        this.jfyqclfs = jfyqclfs;
    }

    public Integer getJfyqxxrn() {
        return jfyqxxrn;
    }

    public void setJfyqxxrn(Integer jfyqxxrn) {
        this.jfyqxxrn = jfyqxxrn;
    }

    public Double getJfyqxrnwfzxwyj() {
        return jfyqxrnwfzxwyj;
    }

    public void setJfyqxrnwfzxwyj(Double jfyqxrnwfzxwyj) {
        this.jfyqxrnwfzxwyj = jfyqxrnwfzxwyj;
    }

    public Integer getJfyqcxxr() {
        return jfyqcxxr;
    }

    public void setJfyqcxxr(Integer jfyqcxxr) {
        this.jfyqcxxr = jfyqcxxr;
    }

    public Integer getYqcjflx() {
        return yqcjflx;
    }

    public void setYqcjflx(Integer yqcjflx) {
        this.yqcjflx = yqcjflx;
    }

    public Double getYqcwyj() {
        return yqcwyj;
    }

    public void setYqcwyj(Double yqcwyj) {
        this.yqcwyj = yqcwyj;
    }

    public Double getFjkwfzxwyj() {
        return fjkwfzxwyj;
    }

    public void setFjkwfzxwyj(Double fjkwfzxwyj) {
        this.fjkwfzxwyj = fjkwfzxwyj;
    }

    public String getJfyqqtfs() {
        return jfyqqtfs;
    }

    public void setJfyqqtfs(String jfyqqtfs) {
        this.jfyqqtfs = jfyqqtfs;
    }

    public String getJftjfhx4() {
        return jftjfhx4;
    }

    public void setJftjfhx4(String jftjfhx4) {
        this.jftjfhx4 = jftjfhx4;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}

==> estateplat-common-1.2.3-20180531.060716-104-sources.jar: cn/gtmap/estateplat/model/commodityHouse/contract/FcjyXjspfBaMmhtJftjsx.java <==
package cn.gtmap.estateplat.model.commodityHouse.contract;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/*
 * @author <a href="mailto:zhangguangguang@gtmap.cn">zhangguangguang</a>
 * @version 1.0, 2018/04/20
 * @description    商品房交付条件与交付手续历史表(第四章)
 */
@Table(name = "fcjy_xjspf_ba_mmht_jftjsx")
public class FcjyXjspfBaMmhtJftjsx implements Serializable {
    @Id
    private String jflsid;//主键
    private String htlsid;//合同历史表id
    private String jfid;//商品房交付条件与交付手续(第四章)主键
    private String htid;//合同ID
    private String jftjfhx3;//交付条件符合项3
    private String jftj3;//交付条件三
    private String jftj4;//交付条件四
    private String gsqt;//供水其他
    private String gdqt;//供电其他
    private String gnqt;//供暖其他
    private String rqqt;//燃气其他
    private Integer jcssyqjfclfs;//基础设施逾期交付处理方式
    private Double dwxzfwyjje;//第五项支付违约金金额(元)
    private Double dlxzfwyjje;//第六项支付违约金金额(元)
    private Double dqxzfwyjje;//第七项支付违约金金额(元)
    private Integer xcbzjfts;//下次保证交付天数
    private String jcssyqjfqtfs;//基础设施逾期交付其他方式
    private Date ldlqx;//绿地率期限
    private String ldldd;//绿地率达到
    private Date fszdlqx;//非市政道路期限
    private String fszdldd;//非市政道路达到
    private Date ghcwqx;//规划车位期限
    private String ghcwdd;//规划车位达到
    private Date wyfwyfqx;//物业服务用房期限
    private String wyfwyfdd;//物业服务用房达到
    private Date ylwsjgqx;//医疗卫生机构期限
    private String ylwsjgdd;//医疗卫生机构达到
    private Date yeyqx;//幼儿园期限
    private String yeydd;//幼儿园达到
    private Date xxqx;//学校期限
    private String xxdd;//学校达到
    private String ptssqt1;//配套设施其他1
    private String ptssqt2;//配套设施其他2
    private String ldlwddclfs;//绿地率未达到处理方式
    private String fszdlwddclfs;//非市政道路未达到处理方式
    private String ghcwwddclfs;//规划车位未达到处理方式
    private String wyfwwddclfs;//物业服务未达到处理方式
    private String qtsswddclfs;//其他设施未达到处理方式
    private Date jfsj;//交付时间
    private Integer jftzts;//交付通知天数
    private String jfqt;//交付其他
    private Integer xxrnxf;//查验次日起XX日内修复
    private String xfnr1;//修复内容其他1
    private String xfnr2;//修复内容其他2
    private String cywjfcl1;//查验未交付处理1
    private String cywjfcl2;//查验未交付处理2
    private Integer jfyqclfs;//交付逾期处理方式
    private Integer jfyqxxrn;//交付逾期XX日内
    private Double jfyqxrnwfzxwyj;//交付逾期X日内万分之X违约金
    private Integer jfyqcxxr;//交付逾期超XX日
    private Integer yqcjflx;//逾期超给付利息(日)
    private Double yqcwyj;//逾期超违约金(百分之)
    private Double fjkwfzxwyj;//房价款万分之X违约金
    private String jfyqqtfs;//交付逾期其他方式
    private String jftjfhx4;//交付条件符合项4
    private Date lssj;//历史时间
    private Integer lscs;//历史次数

    public String getJflsid() {
        return jflsid;
    }

    public void setJflsid(String jflsid) {
        this.jflsid = jflsid;
    }

    public String getHtlsid() { return htlsid; }

    public void setHtlsid(String htlsid) { this.htlsid = htlsid; }

    public String getJfid() {
        return jfid;
    }

    public void setJfid(String jfid) {
        this.jfid = jfid;
    }

    public String getHtid() {
        return htid;
    }

    public void setHtid(String htid) {
        this.htid = htid;
    }

    public String getJftjfhx3() {
        return jftjfhx3;
    }

    public void setJftjfhx3(String jftjfhx3) {
        this.jftjfhx3 = jftjfhx3;
    }

    public String getJftj3() {
        return jftj3;
    }

    public void setJftj3(String jftj3) {
        this.jftj3 = jftj3;
    }

    public String getJftj4() {
        return jftj4;
    }

    public void setJftj4(String jftj4) {
        this.jftj4 = jftj4;
    }

    public String getGsqt() {
        return gsqt;
    }

    public void setGsqt(String gsqt) {
        this.gsqt = gsqt;
    }

    public String getGdqt() {
        return gdqt;
    }

    public void setGdqt(String gdqt) {
        this.gdqt = gdqt;
    }

    public String getGnqt() {
        return gnqt;
    }

    public void setGnqt(String gnqt) {
        this.gnqt = gnqt;
    }

    public String getRqqt() {
        return rqqt;
    }

    public void setRqqt(String rqqt) {
        this.rqqt = rqqt;
    }

    public Integer getJcssyqjfclfs() {
        return jcssyqjfclfs;
    }

    public void setJcssyqjfclfs(Integer jcssyqjfclfs) {
        this.jcssyqjfclfs = jcssyqjfclfs;
    }

    public Double getDwxzfwyjje() {
        return dwxzfwyjje;
    }

    public void setDwxzfwyjje(Double dwxzfwyjje) {
        this.dwxzfwyjje = dwxzfwyjje;
    }

    public Double getDlxzfwyjje() {
        return dlxzfwyjje;
    }

    public void setDlxzfwyjje(Double dlxzfwyjje) {
        this.dlxzfwyjje = dlxzfwyjje;
    }

    public Double getDqxzfwyjje() {
        return dqxzfwyjje;
    }

    public void setDqxzfwyjje(Double dqxzfwyjje) {
        this.dqxzfwyjje = dqxzfwyjje;
    }

    public Integer getXcbzjfts() {
        return xcbzjfts;
    }

    public void setXcbzjfts(Integer xcbzjfts) {
        this.xcbzjfts = xcbzjfts;
    }

    public String getJcssyqjfqtfs() {
        return jcssyqjfqtfs;
    }

    public void setJcssyqjfqtfs(String jcssyqjfqtfs) {
        this.jcssyqjfqtfs = jcssyqjfqtfs;
    }

    public Date getLdlqx() {
        return ldlqx;
    }

    public void setLdlqx(Date ldlqx) {
        this.ldlqx = ldlqx;
    }

    public String getLdldd() {
        return ldldd;
    }

    public void setLdldd(String ldldd) {
        this.ldldd = ldldd;
    }

    public Date getFszdlqx() {
        return fszdlqx;
    }

    public void setFszdlqx(Date fszdlqx) {
        this.fszdlqx = fszdlqx;
    }

    public String getFszdldd() {
        return fszdldd;
    }

    public void setFszdldd(String fszdldd) {
        this.fszdldd = fszdldd;
    }

    public Date getGhcwqx() {
        return ghcwqx;
    }

    public void setGhcwqx(Date ghcwqx) {
        this.ghcwqx = ghcwqx;
    }

    public String getGhcwdd() {
        return ghcwdd;
    }

    public void setGhcwdd(String ghcwdd) {
        this.ghcwdd = ghcwdd;
    }

    public Date getWyfwyfqx() {
        return wyfwyfqx;
    }

    public void setWyfwyfqx(Date wyfwyfqx) {
        this.wyfwyfqx = wyfwyfqx;
    }

    public String getWyfwyfdd() {
        return wyfwyfdd;
    }

    public void setWyfwyfdd(String wyfwyfdd) {
        this.wyfwyfdd = wyfwyfdd;
    }

    public Date getYlwsjgqx() {
        return ylwsjgqx;
    }

    public void setYlwsjgqx(Date ylwsjgqx) {
        this.ylwsjgqx = ylwsjgqx;
    }

    public String getYlwsjgdd() {
        return ylwsjgdd;
    }

    public void setYlwsjgdd(String ylwsjgdd) {
        this.ylwsjgdd = ylwsjgdd;
    }

    public Date getYeyqx() {
        return yeyqx;
    }

    public void setYeyqx(Date yeyqx) {
        this.yeyqx = yeyqx;
    }

    public String getYeydd() {
        return yeydd;
    }

    public void setYeydd(String yeydd) {
        this.yeydd = yeydd;
    }

    public Date getXxqx() {
        return xxqx;
    }

    public void setXxqx(Date xxqx) {
        this.xxqx = xxqx;
    }

    public String getXxdd() {
        return xxdd;
    }

    public void setXxdd(String xxdd) {
        this.xxdd = xxdd;
    }

    public String getPtssqt1() {
        return ptssqt1;
    }

    public void setPtssqt1(String ptssqt1) {
        this.ptssqt1 = ptssqt1;
    }

    public String getPtssqt2() {
        return ptssqt2;
    }

    public void setPtssqt2(String ptssqt2) {
        this.ptssqt2 = ptssqt2;
    }

    public String getLdlwddclfs() {
        return ldlwddclfs;
    }

    public void setLdlwddclfs(String ldlwddclfs) {
        this.ldlwddclfs = ldlwddclfs;
    }

    public String getFszdlwddclfs() {
        return fszdlwddclfs;
    }

    public void setFszdlwddclfs(String fszdlwddclfs) {
        this.fszdlwddclfs = fszdlwddclfs;
    }

    public String getGhcwwddclfs() {
        return ghcwwddclfs;
    }

    public void setGhcwwddclfs(String ghcwwddclfs) {
        this.ghcwwddclfs = ghcwwddclfs;
    }

    public String getWyfwwddclfs() {
        return wyfwwddclfs;
    }

    public void setWyfwwddclfs(String wyfwwddclfs) {
        this.wyfwwddclfs = wyfwwddclfs;
    }

    public String getQtsswddclfs() {
        return qtsswddclfs;
    }

    public void setQtsswddclfs(String qtsswddclfs) {
        this.qtsswddclfs = qtsswddclfs;
    }

    public Date getJfsj() {
        return jfsj;
    }

    public void setJfsj(Date jfsj) {
        this.jfsj = jfsj;
    }

    public Integer getJftzts() {
        return jftzts;
    }

    public void setJftzts(Integer jftzts) {
        this.jftzts = jftzts;
    }

    public String getJfqt() {
        return jfqt;
    }

    public void setJfqt(String jfqt) {
        this.jfqt = jfqt;
    }

    public Integer getXxrnxf() {
        return xxrnxf;
    }

    public void setXxrnxf(Integer xxrnxf) {
        this.xxrnxf = xxrnxf;
    }

    public String getXfnr1() {
        return xfnr1;
    }

    public void setXfnr1(String xfnr1) {
        this.xfnr1 = xfnr1;
    }

    public String getXfnr2() {
        return xfnr2;
    }

    public void setXfnr2(String xfnr2) {
        this.xfnr2 = xfnr2;
    }

    public String getCywjfcl1() {
        return cywjfcl1;
    }

    public void setCywjfcl1(String cywjfcl1) {
        this.cywjfcl1 = cywjfcl1;
    }

    public String getCywjfcl2() {
        return cywjfcl2;
    }

    public void setCywjfcl2(String cywjfcl2) {
        this.cywjfcl2 = cywjfcl2;
    }

    public Integer getJfyqclfs() {
        return jfyqclfs;
    }

    public void setJfyqclfs(Integer jfyqclfs) {
        this.jfyqclfs = jfyqclfs;
    }

    public Integer getJfyqxxrn() {
        return jfyqxxrn;
    }

    public void setJfyqxxrn(Integer jfyqxxrn) {
        this.jfyqxxrn = jfyqxxrn;
    }

    public Double getJfyqxrnwfzxwyj() {
        return jfyqxrnwfzxwyj;
    }

    public void setJfyqxrnwfzxwyj(Double jfyqxrnwfzxwyj) {
        this.jfyqxrnwfzxwyj = jfyqxrnwfzxwyj;
    }

    public Integer getJfyqcxxr() {
        return jfyqcxxr;
    }

    public void setJfyqcxxr(Integer jfyqcxxr) {
        this.jfyqcxxr = jfyqcxxr;
    }

    public Integer getYqcjflx() {
        return yqcjflx;
    }

    public void setYqcjflx(Integer yqcjflx) {
        this.yqcjflx = yqcjflx;
    }

    public Double getYqcwyj() {
        return yqcwyj;
    }

    public void setYqcwyj(Double yqcwyj) {
        this.yqcwyj = yqcwyj;
    }

    public Double getFjkwfzxwyj() {
        return fjkwfzxwyj;
    }

    public void setFjkwfzxwyj(Double fjkwfzxwyj) {
        this.fjkwfzxwyj = fjkwfzxwyj;
    }

    public String getJfyqqtfs() {
        return jfyqqtfs;
    }

    public void setJfyqqtfs(String jfyqqtfs) {
        this.jfyqqtfs = jfyqqtfs;
    }

    public String getJftjfhx4() {
        return jftjfhx4;
    }

    public void setJftjfhx4(String jftjfhx4) {
        this.jftjfhx4 = jftjfhx4;
    }

    public Date getLssj() { return lssj;}

    public void setLssj(Date lssj) { this.lssj = lssj;}

    public Integer getLscs() { return lscs; }

    public void setLscs(Integer lscs) { this.lscs = lscs; }
}
